/*
 
 //This file is licensed under the terms of the CC-LGPL
 
 CL_rlp_integral_test.pov
 
 Here's a demonstration of how you might make fonts with the rlp macros.
 
*/
  ////
 //   example   //
//_____________//  
// Objects can be over- and/or under-embellished in several ways, and text strings, 
// in super- or sub-script size can appear over and/or under the embellished object.
// 
// Over embellishment:
//  0) No over embellishment;
//  1) Over lined;
//  2) Over tilded;
//  3) Over vectored;
//  4) Over caretted; 
//  5) Over right harpooned
//  6) Over curly braced;
//  7) Over acute accent;
//  8) Over grave accent;
//  9) Over small circle;
// 10) Over single dot;
// 11) Over double dot;
// 12) Square/Rounded corner box around the object. Not sure why this is here.
//
// Under embellishment:
//  0) No under embellishment
//  1) Under lined              based on y = 0;
//  2) Under lined              based on the drop below of the object;
//  3) Under tilded             based on y = 0;
//  4) Under tilded             based on the drop below of the object;  
//  5) Under vectored           based on y = 0;
//  6) Under vectored           based on the drop below of the object;
//  7) Under right harpooned    based on y = 0;  
//  8) Under left harpooned     based on the drop below of the object;
//  9) Under curly braced       based on the drop below of the object; 
// 10) Under cedilla            based on y = 0;
// 11) Square/Rounded corner box around the object;
//
// Over embellishment is done before under embellishment.
//
// Since both over- and under-embellishment can be with a box, a double boxed object is 
// available
//
// You can also have centred under- and over- text strings that go under or over 
// the embellishment, if there is one.
//
// By default, many embellishments will be stretched horizontally to cover the whole width of the object
// and all embellishments will be placed in a (hopefully) sensible default position. You can use 
// #local embellish_adjust = array[4][4]{{add_scale_x, add_scale_y , shift_x, shift_y},  // Over  text
//                                       {add_dist_x , add_scale_y , shift_x, shift_y},  // Over  embellishment
//                                       {add_dist_x , add_scale_y , shift_x, shift_y},  // Under embellishment
//                                       {add_scale_x, add_scale_y , shift_x, shift_y},  // Under text
//                                       {add_to_gap , add_to_thick, out_rad, inn_rad}}; // Outer box
//
// The contents of embellish_adjust can be initially left at all zeros. If adjustment is required, 
// they are used as follows;
// add_dist_x  add or subtract a distance to the x-width of the embellishemnt. This dictates a scale factor. 
// add_scale_y add or subtract an amount to the scale factor in the y-direction. Thus 1 doubles the size 
//             and -0.4 results in a 0.6 scale factor.
// shift_x     add or subtract a shift in the x direction. shift_x = add_dist_x/2 will keep a scaled 
//             embellishment centered over the object.
// shift_y     move the embellishment up or down.
// 
//
// Over and under text are scaled by 0.6 then multiplied by (1 + add_scale_x) or (1 + add_scale_y), so add_scale_x = 0.67 restores them to full size.
//
// Over and under embellishments may be scaled across the whole width of the main object. This apparent width can be changed with add_dist_x.
// The default y scale for the embellishment is 1, which is added to by add_scale_y 
// Once the embellishment has been lengthened/shortened, it can be shifted. 
//
// When the embellishment is a box, the meanings are as for the outer box. Default gap is 0.3, Default thick is 0.3. These can't be reduced 
// below 0.1 however negative add_to_gap and add_to_thick are. 
//
// Over embellishing an i or a j conventionally removes the dot. The unit vectors are available as #|1 and #|2, 
// in math mode but if you want other over-embellishments, the no-dot characters are available as CL_rlp_imath and 
// CL_rlp_jmath. 
//
#version 3.7
#global_settings{charset utf8 assumed_gamma 1.0}
//
#include "colors.inc"
#include "chars.inc"
#include "rlp.inc"
#include "CL_rlp_capital_letters_160714.inc" 
// 
CL_rlp_make_text_string_set(1) // Defines CL_tiny_space,CL_small_space,CL_medium_space,CL_large_space,CL_huge_space,CL_letter_adjust,
//                                        CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type as globals
//************************************************************************************************************************************
// Fiddle with these two
#declare CL_debug_lines = 1;   // 1 puts boxes around the different components of the embellished object, 0 doesn't.
#declare embellish_example_type = 1;
//************************************************************************************************************************************
#switch(embellish_example_type)
  #case(1)
// Over harpoon: vector from A to B
    #declare embellish_adjust   = array[5][4]{{0,0,0,0},{-0.5,0,0.5,0},{0,0,0,0},{0,0,0,0},{0,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj            = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                            CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                            0,"#AB",5,0,"","",0,embellish_adjust,0,CL_dimensions_out) }
    #declare camera_z_dist      = 20;    
    #declare camera_y_height    = 1.0;
// Create the object
    object{emb_obj pigment{rgb <0.9,0.9,0.9>} translate <-CL_dimensions_out[0]/2,0,0>}
    #break
//*************************************************************************************************************************************************
  #case(2)
// Over caret: angle at O 
    #declare embellish_adjust   = array[5][4]{{0,0,0,0},{-2,0,1.3,0},{0,0,0,0},{0,0,0,0},{0,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj            = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                            CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                            0,"#AOB",4,0,"","",0,embellish_adjust,0,CL_dimensions_out) }
    #declare camera_z_dist      = 25;    
    #declare camera_y_height    = 1.5;
// Create the object
    object{emb_obj pigment{rgb <0.9,0.9,0.9>} translate <-CL_dimensions_out[0]/2,0,0>}
    #break
//*************************************************************************************************************************************************
  #case(3)    
// second derivative of a vector, with subscript
    #declare embellish_adjust   = array[5][4]{{0,0,0,0},{0,0,0,0},{-0.6,0,0,0},{0,0,0,0},{0,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj            = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                                CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                0,"#x|!_i",11,3,"","",0,embellish_adjust,0,CL_dimensions_out) }
    #declare camera_z_dist      = 20; 
    #declare camera_y_height    = 0.5;
// Create the object
    object{emb_obj pigment{rgb <0.9,0.9,0.9>} translate <-CL_dimensions_out[0]/2,0,0>}
    #break
//*************************************************************************************************************************************************
  #case(4)                                                                                     
// Left/right harpoons with over and under reaction rates (Dissociation of calcium hydroxide). 
// Also using CL_letter_adjust to fiddle with the heights of a 2 character superscript.   
    #declare CL_letter_adjust[1][18] =  0.26; 
    #declare CL_letter_adjust[1][28] = -0.2;
    #declare embellish_adjust   = array[5][4]{{0,0,-2,-0.7},{0,0,0,0},{0,0,0,0},{0,0,-2,1},{0,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj            = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                                CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                0,"#Ca(OH)_2# |h #Ca^+^+ + 2OH^-",0,0,"#k_1","#k_2",0,embellish_adjust,0,CL_dimensions_out) }
// Create the object
    object{emb_obj pigment{rgb <0.9,0.9,0.9>} translate <-CL_dimensions_out[0]/2,0,0>}
    #declare camera_z_dist      = 120; 
    #declare camera_y_height    = 0.5;
    #break
//*************************************************************************************************************************************************
  #case(5)
// Over and under curly braces, with over and under text and an outer box
    #declare embellish_adjust   = array[5][4]{{0.67,0.67,-4,0.5},{-24.5,1,8,0.5},{-5.5,1,0,-0.5},{0.67,0.67,-2.75,0},{1,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj            = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                                CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                0,"#1 + 3 + 5 + 7 + 9 + 11 + 13 = 49",6,9,"#21 = 3|*7","#49 = 7|*7",1,embellish_adjust,0,CL_dimensions_out) }
    #declare camera_z_dist      = 150; 
    #declare camera_y_height    = 0.5;
// Create the object
    object{emb_obj pigment{rgb <0.9,0.9,0.9>} translate <-CL_dimensions_out[0]/2,0,0>} 
    #break
//*************************************************************************************************************************************************
  #case(6)
    #declare CL_debug_lines = 0;
// All the examples
// Over and under curly braces, with over and under text and an outer box
    #declare embellish_adjust   = array[5][4]{{0.67,0.67,-4,0.5},{-24.5,1,8,0.5},{-5.5,1,0,-0.5},{0.67,0.67,-2.75,0},{1,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj_1          = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                                CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                0,"#1 + 3 + 5 + 7 + 9 + 11 + 13 = 49",6,9,"#21 = 3|*7","#49 = 7|*7",1,embellish_adjust,0,CL_dimensions_out) }
// Left/right harpoons with over and under reaction rates (Dissociation of calcium hydroxide). 
// Also using CL_letter_adjust to fiddle with the heights of a 2 character superscript.   
    #declare CL_letter_adjust[1][18] =  0.26; 
    #declare CL_letter_adjust[1][28] = -0.2;
    #declare embellish_adjust   = array[5][4]{{0,0,-2,-0.7},{0,0,0,0},{0,0,0,0},{0,0,-2,1},{0,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj_2            = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                                CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                0,"#Ca(OH)_2# |h #Ca^+^+ + 2OH^-",0,0,"#k_1","#k_2",0,embellish_adjust,0,CL_dimensions_out) }
// Over harpoon: vector from A to B
    #declare embellish_adjust   = array[5][4]{{0,0,0,0},{-0.5,0,0.5,0},{0,0,0,0},{0,0,0,0},{0,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj_3          = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                            CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                            0,"#AB",5,0,"","",0,embellish_adjust,0,CL_dimensions_out) }
// Over caret: angle at O 
    #declare embellish_adjust   = array[5][4]{{0,0,0,0},{-2,0,1.3,0},{0,0,0,0},{0,0,0,0},{0,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj_4          = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                            CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                            0,"#AOB",4,0,"","",0,embellish_adjust,0,CL_dimensions_out) }
// second derivative of a vector, with subscript
    #declare embellish_adjust   = array[5][4]{{0,0,0,0},{0,0,0,0},{-0.6,0,0,0},{0,0,0,0},{0,0,0,0}};  // Over text, over embellish, under embellish, under text
    #declare emb_obj_5          = object{CL_rlp_make_embellish(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_letter_adjust,
                                                                CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                0,"#x|!_i",11,3,"","",0,embellish_adjust,0,CL_dimensions_out) }
    #declare camera_z_dist      = 150; 
    #declare camera_y_height    = 0;
// Create the object
    object{emb_obj_1 pigment{rgb <0.9,0.9,0.9>} translate <-18.5,  6,0>}
    object{emb_obj_2 pigment{rgb <0.9,0.9,0.9>} translate <-14.5, -5,0>}
    object{emb_obj_3 pigment{rgb <0.9,0.9,0.9>} translate <-14.5,-12,0>}
    object{emb_obj_4 pigment{rgb <0.9,0.9,0.9>} translate < -3  ,-12,0>}
    object{emb_obj_5 pigment{rgb <0.9,0.9,0.9>} translate < 12  ,-12,0>}
//
#end 
  ////
 //  end example  //
//_______________//
light_source{<0,20,-25>, 4 fade_power 2 fade_distance 10
  #if(0)
    area_light x*2,y*2,8,8
    jitter adaptive 2
    area_illumination
  #end
            }

camera{orthographic location<0,camera_y_height,-camera_z_dist> look_at <0,camera_y_height,0> angle 15}

